==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/iw.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "ניהול פרמטרי Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "נהל גלריה");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "רוחב תמונה בגודל מלא");
define('MANAGE_GALLERY_FULL_HEIGHT', "גובה תמונה בגודל מלא");
define('MANAGE_GALLERY_THUMB_WIDTH', "רוחב תמונה ממוזערת");
define('MANAGE_GALLERY_THUMB_HEIGHT', "גובה תמונה ממוזערת");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "שמור על יחס גובה-רוחב אגודל");
define('MANAGE_GALLERY_SHOW_TITLES', "הצג כותרות");
define('MANAGE_GALLERY_DISABLE_SORT', "מיין שבת");
define('MANAGE_GALLERY_DELETE_IMAGE', "מחק תמונה");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "שמור סוג סידור");
define('MANAGE_GALLERY_PUBLISH_MSG', "לחץ על &#39;עדכן&#39; לפרסם <br /> תמונות שהעלו.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "כל התמונות כבר לשנות את גודלן ואת ההגדרות נשמרו.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "ארעה שגיאה שינוי גודל התמונות או שמירת הגדרות.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "התמונה שלך (ים) הועלתה.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "אירעה שגיאה בעת טעינת התמונה שלך (ים).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "הקובץ שאתה מנסה להעלות היא לא תמונה.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "הקובץ שאתה מנסה לטעון גדול מדי.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "הכותרת נשמרה.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "האם אתה בטוח שאתה רוצה למחוק תמונה");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "התמונה נמחקה.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "אירעה שגיאה בעת מחיקת התמונה.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "שמירת פרמטרים גודל התמונות, אנא המתן ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "העלאה, אנא המתן ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "סדר המיון לא נשמר. האם ברצונך לשמור את סדר המיון?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "סדר מיון התמונה נשמר.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "אירעה שגיאה בעת שמירת מעין התמונה.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/iw.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "ניהול פרמטרי Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "נהל גלריה");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "רוחב תמונה בגודל מלא");
define('MANAGE_GALLERY_FULL_HEIGHT', "גובה תמונה בגודל מלא");
define('MANAGE_GALLERY_THUMB_WIDTH', "רוחב תמונה ממוזערת");
define('MANAGE_GALLERY_THUMB_HEIGHT', "גובה תמונה ממוזערת");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "שמור על יחס גובה-רוחב אגודל");
define('MANAGE_GALLERY_SHOW_TITLES', "הצג כותרות");
define('MANAGE_GALLERY_DISABLE_SORT', "מיין שבת");
define('MANAGE_GALLERY_DELETE_IMAGE', "מחק תמונה");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "שמור סוג סידור");
define('MANAGE_GALLERY_PUBLISH_MSG', "לחץ על &#39;עדכן&#39; לפרסם <br /> תמונות שהעלו.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "כל התמונות כבר לשנות את גודלן ואת ההגדרות נשמרו.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "ארעה שגיאה שינוי גודל התמונות או שמירת הגדרות.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "התמונה שלך (ים) הועלתה.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "אירעה שגיאה בעת טעינת התמונה שלך (ים).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "הקובץ שאתה מנסה להעלות היא לא תמונה.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "הקובץ שאתה מנסה לטעון גדול מדי.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "הכותרת נשמרה.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "האם אתה בטוח שאתה רוצה למחוק תמונה");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "התמונה נמחקה.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "אירעה שגיאה בעת מחיקת התמונה.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "שמירת פרמטרים גודל התמונות, אנא המתן ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "העלאה, אנא המתן ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "סדר המיון לא נשמר. האם ברצונך לשמור את סדר המיון?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "סדר מיון התמונה נשמר.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "אירעה שגיאה בעת שמירת מעין התמונה.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "הקובץ שאתה מנסה להעלות גדול מהגדרות ה- &#39;upload_max_filesize&#39; או מההודעה &#39;post_max_size&#39;. צור קשר עם מנהל המערכת שלך כדי להגדיל את המגבלות.");
?>
